#
# spec file for package testng
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           testng
Version:        7.10.2
Release:        1.1
Summary:        Java-based testing framework
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://testng.org/
Source0:        %{name}-%{version}.tar.xz
Source1:        https://repo1.maven.org/maven2/org/testng/testng/%{version}/testng-%{version}.pom
Source2:        %{name}-build.xml
Patch0:         0001-Avoid-accidental-javascript-in-javadoc.patch
Patch1:         0002-Replace-bundled-jquery-with-CDN-link.patch
Patch2:         0003-Preserve-Java-8-compatibility.patch
BuildRequires:  ant
BuildRequires:  beust-jcommander
BuildRequires:  fdupes
BuildRequires:  google-guice
BuildRequires:  javapackages-local >= 6
BuildRequires:  jsr-305
BuildRequires:  slf4j
BuildRequires:  snakeyaml >= 2.0
BuildArch:      noarch

%description
TestNG is a testing framework inspired from JUnit and NUnit but introducing
some new functionality, including flexible test configuration, and
distributed test running.  It is designed to cover unit tests as well as
functional, end-to-end, integration, etc.

%package javadoc
Summary:        API documentation for %{name}
Group:          Documentation/HTML

%description javadoc
This package contains the API documentation for %{name}.

%prep
%setup -q
cp %{SOURCE1} pom.xml
cp %{SOURCE2} build.xml
cp -p testng-core/src/main/java/*.dtd.html testng-core/src/main/resources/

%patch -P 0 -p1
%patch -P 1 -p1
%patch -P 2 -p1

%pom_remove_dep org.webjars:jquery

%build
mkdir -p lib
build-jar-repository -s lib beust-jcommander guice/google-guice jsr-305 slf4j/api snakeyaml
%{ant} jar javadoc

%install
# jar
install -dm 0755 %{buildroot}%{_javadir}
install -pm 0644 target/%{name}-%{version}.jar %{buildroot}%{_javadir}/%{name}.jar

# pom
install -dm 0755 %{buildroot}%{_mavenpomdir}
%{mvn_install_pom} pom.xml %{buildroot}%{_mavenpomdir}/%{name}.pom
%add_maven_depmap %{name}.pom %{name}.jar -a org.testng:testng::jdk15:

# javadoc
install -dm 0755 %{buildroot}%{_javadocdir}/%{name}
cp -pr target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}/
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%doc CHANGES.txt README.md
%license LICENSE.txt

%files javadoc
%{_javadocdir}/%{name}
%license LICENSE.txt

%changelog
* Fri Oct  4 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 7.10.2
  * Changes
    + GITHUB-3117: ListenerComparator doesn't work
* Tue Apr 16 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 7.10.1
  * Changes of 7.10.1
    + Fix for #3110
  * Changes of 7.10.0
    + Clean-up deprecated code
    + Minor discrepancy fixes
    + Deleting TestNG eclipse plugin specific classes
    + Code clean-up
    + Remove deprecated JUnit related support in TestNG
    + Handle exceptions in emailable Reporter
    + Add wrapperbot and update workflow order
    + Support ITestNGFactory customisation
    + Streamline data provider listener invocation
    + Streamline Guice Module creation in concurrency.
    + Copy test result attributes when unexpected failures
    + chore: use explicit dependency versions instead of
    refreshVersions
    + Remove Ant
    + Support ordering of listeners
    + Add errorprone
    + Allow custom thread pool executors to be wired in.
    + Allow data providers to be non cacheable
    + Use Locks instead of synchronised keyword
    + Document pgp artifact signing keys
    + Add Unique Id for all test class instances
    + Adding issue management workflows
    + Map object to configurations
    + Allow listeners to be disabled at runtime
    + Streamline Data Provider execution
    + Test case failure
    + Honour inheritance when parsing listener factories
    + Fixing flaky tests
    + Tweaks around accessing SuiteResult
    + Streamline random generation
    + Minor refactoring around RunOrder enum
    + Streamline dependencies for configurations
  * Changes of 7.9.0
    + GitHub 2913
    + Test Results as artifacts for failed runs
    + Minor code clean-ups
    + Fixing the Github CI yaml file
    + Fixing data races
    + Dont honour params specified in suite-file tag
    + Decouple SuiteRunner and TestRunner
    + Disable Native DI for BeforeSuite methods
    + Streamline running Parallel Dataproviders+retries
    + Remove extra whitespace in log for
    Configuration.createMethods()
    + Added the link for TestNG Documentation's GitHub Repo in
    README.md
    + FirstTimeOnlyConfig methods + Listener invocations
    + #2974: Add overrideGroupsFromCliInParentChildXml test
    + Ensure thread safety for attribute access
    + Add @inherited to the Listeners annotation
    + Restrict Group inheritance to Before|AfterGroups
    + Ensure ITestResult injected to @AfterMethod is apt
    + Support suite level thread pools for data provider
    + Minor Code tweaks
    + Favour CompletableFuture instead of PoolService
    + Favour FutureTask for concurrency support
    + Shared Threadpool for normal/datadriven tests.
    + Abort for invalid combinations
  * Changes of 7.8.0
    + XmlTest index is not set for test suites invoked with YAML
    + Listener's onAfterClass is called before @afterclass
    configuration methods are executed.
    + After upgrading to TestNG 7.5.0, setting ITestResult.status
    to FAILURE doesn't fail the test anymore
    + JUnitReportReporter should capture the test case output at
    the test case level
    + [Feature] Allow test classes to define "configfailurepolicy"
    at a per class level
    + TestNG.xml doesn't honour Parallel value of a clone
    + before configuration and before invocation should be 'SKIP'
    when beforeMethod is 'skip'
    + Test listeners specified in parent testng.xml file are not
    included in testng-failed.xml file
    + Discrepancies with DataProvider and Retry of failed tests
    + Skipped Tests with DataProvider appear as failed
    + testng-results xml reports config skips from base classes as
    ignored
    + Feature: Check that specific object present in List
    + Upgrade snakeyaml to 2.0
    + [Feature] Not exception but warning if some (not all) of the
    given test names are not found in suite files.
    + [Feature] Generate testng-results.xml per test suite
  * Changes of 7.7.1
    + Streamline overloaded assertion methods for Groovy
  * Changes of 7.7.0
    + Replace FindBugs by SpotBugs
    + Gradle: Drop forUseAtConfigurationTime()
    + Added ability to provide custom message to
    assertThrows\expectThrows methods
    + Fix issue 2801 - Only resolve hostname once
    + [SECURITY] Fix Zip Slip Vulnerability (bsc#1205628,
    CVE-2022-4065)
    + GITHUB-2807 - Failsafe buildStackTrace
    + Prevent overlogging of debug msgs in Graph impl
    + Streamline dataprovider invoking in abstract classes
    + Streamline TestResult due to expectedExceptions
    + Unexpected test runs count with retry analyzer
    + Make PackageUtils compliant with JPMS
    + Ability to retry a data provider during failures
    + Refactoring
    + Fixing bug with DataProvider retry
    + Add config key for callback discrepancy behavior
    + Upgrading versions
    + Fix #2770: FileAlreadyExistsException on copy
    + JarFileUtils.delete(File f) throw actual exception (instead
    of FileNotFound) when file cannot be deleted #2825
    + GITHUB-2830 - Failsafe parameter.toString
    + Changing assertion message of the osgitest
    + hidden spotbugs in release #2829
    + Enhancing the Matrix
    + Avoid Compilation errors on Semeru JDK flavour.
    + Add addition yml extension
    + Support getting dependencies info for a test
    + Honour regex in dependsOnMethods
    + Ensure All tests run all the time
    + Deprecate support for running Spock Tests
    + Streamline dependsOnMethods for configurations
    + Ensure ITestContext available for JUnit4 tests
    + Deprecate support for running JUnit tests
  * Changes of 7.6.1
    + Fix Files.copy() such that parent dirs are created
    + Remove deprecated utility methods
    + Fix typos
  * Changes of 7.6.0
    + Remove redundant Parameter implementation
    + Upgrade to JDK11
    + Move SimpleBaseTest to be Kotlin based
    + Restore testnames when using suites in suite.
    + Moving ClassHelperTests into Kotlin
    + IHookable and IConfigurable callback discrepancy
    + Minor refactoring
    + Add additional condition for assertEqualsNoOrder
    + beforeConfiguration() listener method should be invoked for
    skipped configurations as well
    + #2734 keep the initial order of listeners
    + SuiteRunner could not be initial by default Configuration
    + Enable Dataprovider failures to be considered.
    + BeforeGroups should run before any matched test
    + Fix possible StringIndexOutOfBoundsException exception in
    XmlReporter
    + DataProvider: possibility to unload dataprovider class, when
    done with it
    + fix possibilty that AfterGroups method is invoked before all
    tests
    + fix equals implementation for WrappedTestNGMethod
    + Upgrade dependencies, Upgrade to JDK17
    + Wire-In listeners consistently
    + Streamline AfterClass invocation
    + Show FQMN for tests in console
    + Fix 2725
- Modified patches:
  * 0001-Avoid-accidental-javascript-in-javadoc.patch
  * 0002-Replace-bundled-jquery-with-CDN-link.patch
    + regenerate for the current version
- Added patch:
  * 0003-Preserve-Java-8-compatibility.patch
    + restore the possibility to build with --release 8
- Removed patches:
  * 0003-Upgrade-snakeyaml-to-2.0.patch
  * 0004-vuln-fix-Zip-Slip-Vulnerability.patch
    + integrated in this version
* Mon Apr 15 2024 Fridrich Strba <fstrba@suse.com>
- Modified patches:
  * 0001-Avoid-accidental-javascript-in-javadoc.patch
  * 0002-Replace-bundled-jquery-with-CDN-link.patch
  * testng-CVE-2022-4065.patch ->
    0004-vuln-fix-Zip-Slip-Vulnerability.patch
    + re-cherry-pick and rediff in git
- Added patch:
  * 0003-Upgrade-snakeyaml-to-2.0.patch
    + Fix build against snakeyaml >= 2.0
* Wed Feb 21 2024 Fridrich Strba <fstrba@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
* Tue Nov 22 2022 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * testng-CVE-2022-4065.patch
    + Issues in sanitization of zip files could lead to path
    traversal and potentially code execution (bsc#1205628,
    CVE-2022-4065)
* Wed Apr 27 2022 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 7.4.0
  * Features:
    + Ability to be notified when a data provider fails, through
    a TestNG listener.
    TestNG already has a listener that will let you plug in your
    callbacks for the following with respect to a data provider
    (implement org.testng.IDataProviderListener interface)
    You can now use this listener to be notified when a data
    provider fails as well.
    + Add the ability to override explicitly included test methods
    if they belong to any excluded groups via the configuration
    property : overrideIncludedMethods
    + Reduced memory foot print when trying to run tests with
    larger projects.
    This is now a toggle feature which can be enabled via the
    JVM argument: -Dtestng.memory.friendly=true
  * Bug fixes:
    + GITHUB-2459: Support configurable start time - emailable
    report
    + GITHUB-2467: XmlTest does not copy the xmlClasses during clone
    + GITHUB-2469: Parameters added in XmlTest during
    AlterSuiteListener not available in SuiteListener
    + GITHUB-2296: Fix for assertEquals not working for sets as
    order is not guaranteed
    + GITHUB-2465: Fix bux where Strings.join returns empty String
    + GITHUB-1632: throwing SkipException sets iTestResult status to
    Failure instead of Skip
    + GITHUB-2456: Add onDataProviderFailure listener
    + GITHUB-2445: NPE in FailedReporter.java With Tests Created in
    Factory
    + GITHUB-2428: Configuration methods have the same test class
    instance when @Factory is being used
    + GITHUB-2440: Fixed an issue when case timeout returned an
    incorrect exception and effect the next other test case
    + GITHUB-2407: Adds "overrideIncludedMethods" to the global
    config as a command-line argument, which excludes explicitly
    included test methods if they belong to any excluded groups
    + GITHUB-2432: Rework MethodInheritance.fixMethodInheritance to
    "soft" dependencies
    + GITHUB-2429: Seggregate Dependency Injection out as a clear
    implementation
    + GITHUB-2435: getParameterIndex() always return 0 in test
    listener
    + GITHUB-2406: TestNG 7.3.0 transitive vulnerability
    CVE-2020-11022 and CVE-2020-11023 due to JQuery 3.4.1
    + GITHUB-2405: Regression: Using TestNG via Maven breaks when
    optional Guice dependency is unavailable
    + GITHUB-2427: Guice module (suite parent-module and test
    module) configure() method is called multiple times
    + GITHUB-2419: TestNG JUnit reports are not valid if system
    output contains XML tags
    + GITHUB-188: suite parallel="methods" does not work when there
    are multiple <test> tags in the testng.xml
    + GITHUB-346: When a method is annotated with both BeforeGroups
    and AfterGroups only AfterGroup is executed
    + GITHUB-2403: Suite.xml files attempt to make web request when
    suite references standard TestNG DTD using HTTP
    + GITHUB-2385: Make @Listeners can work for implemented
    interfaces and Inherited class
    + GITHUB-2053: MethodHelper.collectAndOrderMethods() Hangs when
    Parallel Instance and dependsOnGroups
    + GITHUB-2400: BeforeClass/Method (and AfterClass/Method)
    configuration methods that override default methods are
    invoked multiple times
    + GITHUB-2396: @Ignore on method level doesn't work as expected
    + GITHUB-2382: TestNG version should be specified in MANIFEST.MF
    + GITHUB-2096: 7.0.0-beta6 memory issues (regression)
    + GITHUB-2355: TestNG creates multiple Guice Module Instances
    + GITHUB-2374: Add file name to the warning message
    + GITHUB-2321: -Dtestng.thread.affinity=true do not work when
    running multiple instance of test in parallel
    + GITHUB-2363: JS error when switching theme
    + GITHUB-2361: No way to enforce @Test(singleThreaded = true)
    when test defined in base class
    + GITHUB-2343: Injectors are not reused when they share the same
    set of modules
    + GITHUB-2346: ITestResult attributes are null when retrieved by
    Listener onTestStart if test fails at BeforeMethod
    + GITHUB-2357: TestNG 7.3.0 transitive dependencies
- Fetch sources using source service instead of a script
- Build with java source and target levels 8
- Modified patches:
  * 0001-Avoid-accidental-javascript-in-javadoc.patch
  * 0002-Replace-bundled-jquery-with-CDN-link.patch
    + Rediff to changed context
* Sun Mar 17 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of testng 6.14.3
- Generate and customize ant build.xml file
